@@ -7,6 +7,6 @@
     :license: BSD, see LICENSE for more details
 """
 __name__ = 'dsmtpd'
-__version__ = '0.2.1'
-__author__ = 'Stephane Wirtel',
+__version__ = '0.2.2'
+__author__ = 'Stephane Wirtel'
 __author_email__ = 'stephane@wirtel.be'
